@brief Adds ASSIST functionality to a passed REBOUND simulation.
@param sim Pointer to the reb_simulation on which to add ASSIST functionality.
@return Pointer to an assist_extras structure.
@brief Detaches ASSIST from simulation, resetting all the simulation’s function pointers that ASSIST has set.
@details This does not free the memory allocated by ASSIST (call assist_free).
@param sim Pointer to the simulation from which to remove ASSIST
@brief Output an error message.
@details This function should be used if an error occurs rather than simply using print.
The message will be passed to python.
@param assist The assist_extras pointer.
@param msg The error message.
@brief Frees all memory allocated by ASSIST instance.
@details Should be called after simulation is done if memory is a concern.
@param assist The assist_extras pointer returned from the initial call to assist_attach.